@@ -7,6 +7,10 @@
 
 #define NODESIZE(N) sizeof(Node) + (sizeof(SV*) * (N+1))
 
+#define SV2NODE(S) INT2PTR(Node*, SvIV(SvRV(S)))
+
+#define IV2NODE(S) INT2PTR(Node*, S)
+
 typedef struct {
   SV*   key;
   SV*   value;
@@ -24,6 +28,7 @@ SV* get_child_or_undef(Node * n, int index);
 void set_child(Node* n, int index, SV* t);
 
 void set_key(Node *n, SV* k);
+void force_set_key(Node *n, SV* k);
 SV* get_key(Node *n);
 I32 key_cmp(Node* n, SV* k);
 
@@ -32,4 +37,3 @@ SV* get_value(Node *n);
 
 int _allocated(Node* n);
 
-
